'use client'

import { useState } from 'react'
import { FiDownload, FiRefreshCw } from 'react-icons/fi'
import { QRCodeCanvas } from 'qrcode.react'
import jsPDF from 'jspdf'
import DashboardLayout from '@/components/layout/DashboardLayout'

export default function CreateQRPage() {
  const [url, setUrl] = useState('')
  const [name, setName] = useState('')
  const [showQR, setShowQR] = useState(false)
  
  const generateQR = () => {
    if (!url) {
      alert('Lütfen bir URL girin')
      return
    }
    setShowQR(true)
  }

  const downloadQR = () => {
    const canvas = document.getElementById('qr-code') as HTMLCanvasElement
    if (canvas) {
      // PDF oluştur - QR kodun boyutuna göre kare format
      const pdf = new jsPDF({
        orientation: 'portrait',
        unit: 'mm',
        format: [150, 150] // Kare format, QR kod için ideal
      })
      
      // Canvas'ı base64 formatına çevir
      const imgData = canvas.toDataURL('image/png')
      
      // QR kodu - sayfayı tamamen kaplayacak şekilde
      pdf.addImage(
        imgData,
        'PNG',
        0, // x pozisyonu
        0, // y pozisyonu
        150, // genişlik
        150  // yükseklik
      )
      
      // PDF'i indir
      pdf.save(`${name || 'qr-code'}.pdf`)
    }
  }

  return (
    <DashboardLayout>
      <div className="container mx-auto px-4 py-8">
        <div className="max-w-2xl mx-auto">
          <h1 className="text-2xl font-bold text-slate-800 dark:text-white mb-8">
            QR Kod Oluştur
          </h1>

          <div className="bg-white dark:bg-slate-800 rounded-2xl shadow-sm border border-slate-200 dark:border-slate-700 p-6 mb-6">
            <div className="space-y-4">
              <div>
                <label className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                  URL Adresi
                </label>
                <input
                  type="url"
                  value={url}
                  onChange={(e) => setUrl(e.target.value)}
                  placeholder="https://example.com"
                  className="w-full px-4 py-2.5 rounded-xl border border-slate-200 dark:border-slate-700
                           bg-white dark:bg-slate-800 text-slate-800 dark:text-white
                           focus:ring-2 focus:ring-fuchsia-500/50 focus:border-fuchsia-500"
                />
              </div>
              
              <button
                onClick={generateQR}
                className="w-full px-4 py-2.5 bg-gradient-to-r from-fuchsia-500 to-purple-600
                         text-white font-medium rounded-xl hover:opacity-90 transition-all
                         flex items-center justify-center gap-2"
              >
                <FiRefreshCw className="w-4 h-4" />
                QR Kod Oluştur
              </button>
            </div>
          </div>

          {showQR && (
            <div className="bg-white dark:bg-slate-800 rounded-2xl shadow-sm 
                         border border-slate-200 dark:border-slate-700 p-6 text-center">
              <div className="mb-6 flex justify-center">
                <QRCodeCanvas
                  id="qr-code"
                  value={url}
                  size={300}
                  level="H"
                  includeMargin={true}
                  className="rounded-xl"
                />
              </div>
              
              <button
                onClick={downloadQR}
                className="px-4 py-2.5 bg-gradient-to-r from-fuchsia-500 to-purple-600
                         text-white font-medium rounded-xl hover:opacity-90 transition-all
                         inline-flex items-center gap-2"
              >
                <FiDownload className="w-4 h-4" />
                QR Kodu PDF İndir
              </button>
            </div>
          )}
        </div>
      </div>
    </DashboardLayout>
  )
} 